;; Generated package description from boxy-headings.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "boxy-headings" "2.1.11.0.20260303.182038" "View org files in a boxy diagram" '((emacs "26.1") (boxy "2.0") (org "9.4")) :commit "08e1c84dee28f87010f50cb4e9a48c0798c8912b" :authors '(("Amy Pillow" . "amypillow@lavache.com")) :maintainer '("Amy Pillow" . "amypillow@lavache.com") :keywords '("tools") :url "https://codeberg.org/strawburster/boxy-headings")
